package com.typ.myframework.hibernate;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Savepoint;


public class Session {	
	
	private Connection connection;	
	private SessionFactory sessionFactory;
	private Transaction transaction;
	
	public Session(SessionFactory sessionFactory) {			
		this.sessionFactory = sessionFactory;
		transaction = new Transaction(this);
	}
	
	public void openSession() {
		connection = this.sessionFactory.getConnection();
	}	
	
	public void close() {
		try {
			this.connection.setAutoCommit(this.transaction.autoCommit);
			this.sessionFactory.close(connection);
			this.connection = null;
		} catch (SQLException e) {
			e.printStackTrace();
		}
		this.sessionFactory.close(connection);
	}
	public Connection getConnection() {
		return connection;
	}	
	
	public Transaction getTransaction() {
		return transaction;
	}
	
	public class Transaction {				
		public Session session = null;
		public boolean autoCommit = false;
		
		public Transaction(Session session) {
			this.session = session;		
		}
		
		public void beginTransaction() {
			try {				
				autoCommit = this.session.getConnection().getAutoCommit();
				this.session.getConnection().setAutoCommit(false);			
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		
		public void commit() {			
			try {					
				this.session.getConnection().commit();				
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		
		public void rollback() {
			try {
				if (this.session.getConnection() != null) {
					this.session.getConnection().rollback();					
				}				
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		
		public void rollback(Savepoint sp) {
			try {
				if (this.session.getConnection() != null) {
					this.session.getConnection().rollback(sp);					
				}				
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
	}	
}
